@@ -17,6 +17,11 @@ import aws_cdk.aws_s3
 import aws_cdk.aws_s3_assets
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-s3-deployment", "1.34.0", __name__[0:-6], "aws-s3-deployment@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
